@@ -56,21 +56,29 @@ class BaseSlides:
     def css_styles(self):
         """CSS styles for write(..., className = style)."""
         # self.html will be added from Chid class
-        return self.html('div', '''Use any or combinations of these styles in className argument of writing functions:
-        className = 'Center'            ------Text------
-        className = 'Left'              Text------------
-        className = 'Right'             ------------Text
-        className = 'RTL'               ------ اردو عربی 
-        className = 'Info'              Blue Text
-        className = 'Warning'           Orange Text
-        className = 'Success'           Green Text
-        className = 'Error'             Red Text
-        className = 'Note'              Text with info icon
-        className = 'slides-only'       Text will not appear in exported html with `build_report`
-        className = 'report-only'       Text will not appear on slides. Useful to fill content in report.
-        className = 'Block'             Block of text/objects
-        className = 'Block-[color]'     Block of text/objects with specific background color from red, green, blue, yellow, cyan, magenta and gray.
-        ''',className= 'RawText')
+        return self.raw('''
+        Use any or combinations of these styles in className argument of writing functions:
+        ------------------------------------------------------------------------------------
+         className          | Formatting Style                                              
+        ====================================================================================
+         'Center'           | ------Text------
+         'Left'             | Text------------
+         'Right'            | ------------Text
+         'RTL'              | ------ اردو عربی 
+         'Info'             | Blue Text
+         'Warning'          | Orange Text
+         'Success'          | Green Text
+         'Error'            | Red Text
+         'Note'             | Text with info icon
+         'slides-only'      | Text will not appear in exported html report.
+         'report-only'      | Text will not appear on slides. Use to fill content in report.
+         'page-break'       | Report will break page in print after object with this class.
+         'Block'            | Block of text/objects
+         'Block-[color]'    | Block of text/objects with specific background color from red,
+                            | green, blue, yellow, cyan, magenta and gray.
+         'RawText'          | Text will not be formatted and will be shown as it is.
+        ------------------------------------------------------------------------------------
+        ''')
         
     def get_source(self, title = 'Source Code'):
         "Return source code of all slides created using `from_markdown` or `%%slide`."
@@ -217,54 +225,18 @@ class BaseSlides:
         return handles
     
     def demo(self):
-        """Demo slides with a variety of content."""
-        self.close_view() # Close any previous view to speed up loading 10x faster on average
-        self.clear() # Clear previous content
-        self._citation_mode = 'global' # Set citation mode to global if set otherwise by user
+        "Demo slides with a variety of content."
+        from .. import _demo
+        return _demo.demo(self) # Run demo
         
-        import runpy
-        file = os.path.join(os.path.dirname(os.path.dirname(__file__)), '_demo.py') # Relative path to this file
-        slides = runpy.run_path(file, init_globals= {'slides': self})['slides']
-        
-        N = len(slides)
-        with slides.slide(N + 1):
-            slides.write('## This is all code to generate slides')
-            slides.write(self.demo)
-            slides.source.from_file(file).display()
-            
-        with slides.slide(N + 2):
-            slides.write('Slides made by using `from_markdown` or `%%slide` magic preserve their full code\n{.Note .Info}')
-            slides.get_source().display()
-            
-        with slides.slide(N + 3, props_dict = {'': dict(background='#9ACD32')}):
-            with slides.source.context() as s:
-                slides.write('citations`## Reference via Markdown\n----`',['## Reference via Python API\n----',*slides.citations])
-            s.display()
-        
-        # Just for func, set theme of all even slides to be fancy, and zoom animation
-        fancy_even_slides_css = {       
-            '--heading-fg': '#105599',
-	        '--accent-color': '#955200',
-            '--pointer-color': '#FF7722'
-        }   
-        
-        for s in slides[::2]: 
-            s.set_css({'slide': fancy_even_slides_css})
-            s.set_animation('zoom')
-        
-        slides._slideindex = 0 # Go to title, user should not set this
-        return slides
-    
     def docs(self):
         "Create presentation from docs of IPySlides."
         self.close_view() # Close any previous view to speed up loading 10x faster on average
         self.clear() # Clear previous content
         self.create(*range(13)) # Create slides faster
         
-        from itertools import count
         from ..core import Slides
         from ..__version__ import __version__
-        counter = count(start=1)
         
         self.settings.set_footer('IPySlides Documentation')
         
@@ -272,7 +244,7 @@ class BaseSlides:
             self.write(f'## IPySlides {__version__} Documentation\n### Creating slides with IPySlides')
             self.center('''
                 alert`Abdul Saboor`sup`1`, Unknown Authorsup`2`
-
+                section`Introduction`
                 today``
                 
                 class`TextBox`
@@ -280,57 +252,64 @@ class BaseSlides:
                 sup`2`Their University is somewhere in the middle of nowhere
                 ^^^
                 ''').display()
+        
+        with self.slide(self.auto_number) as slide_toc1: # Need at end to refresh TOC
+            self.write('## Table of Contents')
             
-        with self.slide(next(counter)):
+        with self.slide(self.auto_number):
             self.write(['# Main App',self.doc(Slides)])
         
-        with self.slide(next(counter)):
-            self.write('## Adding Slides')
+        with self.slide(self.auto_number):
+            self.write('## Adding Slides section`Adding Slides and Content`')
             self.write('Besides functions below, you can add slides with `%%title` magics as well.\n{.Note .Info}')
             self.write([self.doc(self.title,'Slides'),self.doc(self.slide,'Slides'),self.doc(self.frames,'Slides'),self.doc(self.from_markdown,'Slides')])
         
-        with self.slide(next(counter)):
+        with self.slide(self.auto_number):
             self.write('## Adding Content')
             self.write('Besides functions below, you can add content to slides with `%%xmd`,`%xmd`, `display(obj)` as well.\n{.Note .Info}')
             self.xmd_syntax.display() # This will display information about Markdown extended syntax
             self.write([self.doc(self.write,'Slides'),self.doc(self.iwrite,'Slides'), self.doc(self.parse_xmd,'Slides'),self.doc(self.cite,'Slides')])
         
-        with self.slide(next(counter)):
+        with self.slide(self.auto_number):
             self.write('## Adding Speaker Notes')
-            self.write([f'You can use alert`notes{self.backtick}notes content{self.backtick}` in markdown.\n{{.Note .Success}}\n',
+            self.write([f'You can use alert`notes\`notes content\`` in markdown.\n{{.Note .Success}}\n',
                        'This is experimental feature, and may not work as expected.\n{.Block-red .Error}'])
             self.doc(self.notes,'Slides.notes', members = True, itself = False).display()
+            self.goto_button(10,'Jump to Slide 10', 'This is kind a alert`alt text` because button will alert`NOT` show in screenshot of slides')
                    
-        with self.slide(next(counter)):
+        with self.slide(self.auto_number):
             self.write('## Displaying Source Code')
             self.doc(self.source,'Slides.source', members = True, itself = False).display()
         
-        with self.slide(next(counter)):
+        with self.slide(self.auto_number)  as slide_toc2: # Need at end to refresh TOC
+            self.write('## Table of Contents section`?Layout and color[yellow_black]`Theme` Settings?`')
+        
+        with self.slide(self.auto_number): 
             self.write('## Layout and Theme Settings')
             self.doc(self.settings,'Slides.settings', members=True,itself = False).display()
                 
-        with self.slide(next(counter)):
-            self.write('## Useful Functions for Rich Content')
-            members = ['suppress_stdout','alert','block', 'bokeh2html', 'cite',
+        with self.slide(self.auto_number):
+            self.write('## Useful Functions for Rich Content section`?Useful Functions for alert`Rich Content`?`')
+            members = ['alert','block', 'bokeh2html', 'bullets','cite',
                        'colored', 'cols', 'details', 'doc','sub','sup', 'today', 'enable_zoom', 'format_css', 'format_html', 'highlight',
                        'html', 'iframe', 'image', 'keep_format', 'notify', 'notify_later', 'plt2html', 'raw', 'rows',
-                       'set_dir', 'sig', 'svg', 'textbox', 'vspace']
+                        'section', 'set_dir', 'sig', 'textbox', 'suppress_output','suppress_stdout','svg', 'vspace']
             self.doc(self.clipboard_image,'Slides').display()
             self.doc(self, 'Slides', members = members, itself = False).display()
             
-        with self.slide(next(counter)):
+        with self.slide(self.auto_number):
             self.write('## Content Styling')
-            with self.source.context() as c:
+            with self.source.context(auto_display = False) as c:
                 self.write(('You can **style**{.Error} or **color[teal]`colorize`** your *content*{: style="color:hotpink;"} and *color[hotpink_yellow]`text`* with `className` attribute in writing/content functions. ' 
                        'Provide **CSS**{.Info} for that using `.format_css` or use some of the available styles. '
                        'See these **styles**{.Success} with `.css_styles` property as below:'))
                 self.css_styles.display()
                 c.display()
         
-        s8, = self.from_markdown(next(counter), '''
+        s8, = self.from_markdown(self.auto_number, '''
         ## Highlighting Code
         [pyg]:`[pygments](https://pygments.org/) is used for syntax highlighting.`
-        You can **highlight**{.Error} code using `highlight`cite`pyg` function or within markdown like this:
+        You can **highlight**{.Error} code using `highlight` function or within markdown like this:cite`pyg`
         ```python
         import ipyslides as isd
         ```
@@ -347,8 +326,8 @@ class BaseSlides:
             self.write(s8.citations)
             s8.source.display()
         
-        with self.slide(next(counter)):
-            self.write('## Loading from File/Exporting to HTML')
+        with self.slide(self.auto_number):
+            self.write('## Loading from File/Exporting to HTML section`Loading from File/Exporting to HTML`')
             self.write('You can parse and view a markdown file w. The output you can save by exporting notebook in other formats.\n{.Note .Info}')
             self.write([self.doc(self.from_markdown,'Slides'),
                         self.doc(self.demo,'Slides'), 
@@ -356,24 +335,30 @@ class BaseSlides:
                         self.doc(self.export.slides,'Slides.export'),
                         self.doc(self.export.report,'Slides.export')])
         
-        with self.slide(next(counter)):
+        with self.slide(self.auto_number) as slide_toc3: # Need at end to refresh TOC
+            self.write('## Table of Contents section`Advanced Functionality`')
+        
+        with self.slide(self.auto_number):
             self.write('## Adding User defined Objects/Markdown Extensions')
             self.write('If you need to serialize your own or third party objects not serialized by this module, you can use `@Slides.serializer.register` to serialize them to html.\n{.Note .Info}')
             self.doc(self.serializer,'Slides.serializer', members = True, itself = False).display()
             self.write('**You can also extend markdown syntax** using `markdown extensions`, ([See here](https://python-markdown.github.io/extensions/) and others to install, then use as below):')
             self.doc(self.extender,'Slides.extender', members = True, itself = False).display()
         
-        with self.slide(next(counter)):
+        with self.slide(self.auto_number):
             self.write('## Keys and Shortcuts\n'
                 '- You can use `Slides.current` to access a slide currently in view.\n'
                 '- You can use `Slides.running` to access the slide currently being built,'
-                ' so you can set CSS, aminations etc.', key_combs)
+                ' so you can set CSS, aminations etc.\n'
+                '- You can use `Slides.auto_number` inside python script for `slide_number` argument. alert`Do NOT` use in Notebook.', key_combs)
         
-        with self.slide(next(counter)):
-            self.write(['## Presentation Code',self.docs])
+        with self.slide(self.auto_number):
+            self.write(['## Presentation Code section`Presentation Code`',self.docs])
         
-        self._slideindex = 0 # Go to title
-        del counter # Delete counter
+        for slide in [slide_toc1, slide_toc2, slide_toc3]:
+            slide.insert_markdown({-1: 'toc`------`'}) # Update table of contents at end
+         
+        self.navigate_to(0) # Go to title
         return self
 
 def _parse_markdown_text(text_block):
