@@ -16,12 +16,13 @@ function main(){
     }; 
     resizeWindow(); // resize on first display
     // Only get buttons of first view, otherwise it will becomes multiclicks
-    let arrows = document.getElementsByClassName('arrows'); // These are 2*instances
-    let mplBtn = document.getElementsByClassName('mpl-zoom')[0];
-    let winFs = document.getElementsByClassName('window-fs')[0];
-    let capSc = document.getElementsByClassName('screenshot-btn')[0];
-    let cursor = document.getElementsByClassName('LaserPointer')[0];
+    let arrows  = document.getElementsByClassName('arrows'); // These are 2*instances
+    let mplBtn  = document.getElementsByClassName('mpl-zoom')[0];
+    let winFs   = document.getElementsByClassName('window-fs')[0];
+    let capSc   = document.getElementsByClassName('screenshot-btn')[0];
+    let cursor  = document.getElementsByClassName('LaserPointer')[0];
     let present = document.getElementsByClassName('presenter-btn')[0];
+    let panelBtn = document.getElementsByClassName('SidePanel-Btn')[0];
 
     
     // Keyboard events
@@ -35,6 +36,8 @@ function main(){
             arrows[1].click(); // Next or Spacebar
         } else if (key === 90) { 
             mplBtn.click(); // Z 
+        } else if (key === 71) { 
+            panelBtn.click(); // G
         } else if (key === 88 || key === 68) {
             alert("Pressing X or D,D may cut selected cell! Click outside slides to capture these keys!");
             e.stopPropagation(); // stop propagation to jupyterlab events
@@ -42,8 +45,17 @@ function main(){
         } else if (key===77){
             alert("Pressing M could change cell to Markdown and vanish away slides!");
             e.stopPropagation();   // M key
+        } else if (key === 87) { 
+            winFs.click(); // Toggle Window with W 
         } else if (key === 70) { 
-            winFs.click(); // F 
+            // F to enter fullscreen
+            document.getElementsByClassName('SlidesWrapper')[0].requestFullscreen();
+            if (!winFs.classList.contains('mod-active')) {
+                winFs.click(); // Make layout fullscreen as well
+            };
+        } else if (key === 27) {  
+            // Escape to exit fullscreen
+            document.getElementsByClassName('SlidesWrapper')[0].exitFullscreen();
         } else if (key === 13) {
             return true; // Enter key
         } else if (key === 83) {
@@ -91,12 +103,49 @@ function main(){
     }
     
 };
+
+// Touch Events are experimental
+function beta_swiper(){
+    let box = document.getElementsByClassName('SlidesWrapper')[0];
+    box.tabIndex = -1;
+    let arrows = document.getElementsByClassName('arrows'); // These are 2*instances
+
+    let startX = 0;
+    let endX = 0;
+    let startY = 0;
+    let endY = 0;
+    box.addEventListener('touchstart', function (event) {
+        startX = event.changedTouches[0].screenX;
+        startY = event.changedTouches[0].screenY;
+    }, false);
+
+    box.addEventListener('touchend', function (event) {
+        endX = event.changedTouches[0].screenX;
+        endY = event.changedTouches[0].screenY;
+        handleGesture();
+    }, false);
+
+    function handleGesture() {
+        let bbox = box.getBoundingClientRect(); // Swipe only from edges
+        if (Math.abs(endY - startY) < 20) {
+            // Y axis is not important but we should avoid X component of touch for a long y-scroll
+            if ((endX - startX) < -40 && startX > (bbox.right - 50)) {
+                arrows[1].click(); // Left Swipe to Next
+            };
+
+            if ((endX - startX) > 40 && startX < (bbox.left + 50)) {
+                arrows[0].click(); // Right Swipe to Prev
+            };
+        }; 
+    };
+};
 // Now execute function to work, handle browser refresh too
 try {
     var waitLoading = setInterval(function() {
         let boxes = document.getElementsByClassName('SlidesWrapper ');
         if (boxes.length >= 1) {
             main(); // Refresh does work in this case
+            beta_swiper(); // Touch events
             clearInterval(waitLoading);
         }
     }, 500); // check every 500ms, I do not need be hurry
