@@ -17,6 +17,7 @@ class _EmptyCaptured: outputs = [] # Just as placeholder for initialization
 class Slide:
     "New in 1.7.0"
     _animations = {'main':'','frame':''}
+    _overall_css = html('style','')
     def __init__(self, app, number, captured_output = _EmptyCaptured, props_dict = {}):
         self._widget = Output(layout = Layout(height='auto',margin='auto',overflow='auto',padding='0.2em 2em'))
         self._app = app
@@ -30,7 +31,7 @@ class Slide:
         self.set_css(props_dict)
         
         self._notes = '' # Should be update by Notes and Slides calss
-        self.set_overall_animation()
+        self._set_overall_animation()
         self._animation = None
         self._markdown = '' # Should be update by Slides
         self._cell_code = '' # Should be update by Slides 
@@ -39,6 +40,7 @@ class Slide:
         self._has_widgets = False # Update in _build_slide function
         self._citations = {} # Added from Slides
         self._frames = [] # Added from Slides
+        self._section = None # Added from Slides
         
     def __repr__(self):
         return f'Slide(number = {self._number}, label = {self.label!r}, index = {self._index})'
@@ -46,13 +48,15 @@ class Slide:
     @contextmanager
     def _capture(self, assign = True):
         "Capture output to this slide."
+        self._app._running_slide = self
         if assign:
+            self._app._next_number = int(self._number) + 1
             self._toast = None # Reset toast
             self._notes = '' # Reset notes
             self._citations = {} # Reset citations
             self._extra_outputs = {'start': [], 'end': []} # Reset extra outputs
+            self._section = None # Reset section
         
-        self._app._running_slide = self
         try:
             with capture_output() as captured:
                 yield captured
@@ -156,13 +160,17 @@ class Slide:
     def label(self):
         return self._label
     
+    @property
+    def number(self):
+        return int(self._number) # Return as int
+    
     @property
     def citations(self):
-        return tuple(self._citations.values())
+        return tuple(sorted(self._citations.values(), key=lambda x: int(x._id)))
     
     @property
     def css(self):
-        return self._css
+        return self._overall_css + self._css # Add overall CSS but self._css should override it
     
     @property
     def index(self):
@@ -211,14 +219,40 @@ class Slide:
         self.update_display() # Needs to not discard widgets there
         return display(self._widget)
     
-    def set_css(self,props_dict):
-        """props_dict is a dict of css properties in format {'selector': {'prop':'value',...},...}
-        'selector' for slide itself should be '' or 'slide'.
+    def _set_overall_css(self, props_dict={}):
+        self.__class__._overall_css = html('style','') # Reset overall CSS
+        old_slide_css = self._css # Save old slide CSS without overall CSS
+        self.set_css(props_dict = props_dict) # Set this slide's CSS
+        self.__class__._overall_css = self.css # Set overall CSS from this slide's CSS, self.css takes both
+        self._css = old_slide_css # Restore old slide CSS
+    
+    def _parse_css(self, selector_dict):
+        # TODO: Parse CSS selector dict for keyframes, media queries, and normal selectors
+        pass
+    
+    def set_css(self,props_dict = {}):
+        """`props_dict` is a nested dict of css properties.      
+        **Example:** 
+        ```python
+        props_dict ={
+            'slide':{'background':'#000'}, # 'slide', '.slide' or '' is a special selector for the slide itself
+            'p': {'color':'#fff', 'animation': '0.2sec animation_name'}, # content selector
+            '@keyframe animation_name':{ 
+                '0%': {'transform':'scale(0.5)'} 
+                '100%': {'transform':'scale(1)'}
+            }, 
+            '@media screen and (max-width: 600px)': {
+                'p': {'color':'#000'}
+            }
+        }
+        ```
         """
         if not isinstance(props_dict, dict):
             raise TypeError("props_dict must be a dict in format {'selector': {'prop':'value',...},...}")
         
         for k, v in props_dict.items():
+            if ('@keyframes' in k) or ('@media' in k):
+                raise NotImplementedError('Keyframes and Media Queries are not implemented yet.')
             if not isinstance(v, dict):
                 raise TypeError('Value for selector {} should be a dict of {"prop":"value",...}, got {}'.format(k,v))
         _all_css = ''
@@ -245,21 +279,27 @@ class Slide:
             with self._app.widgets.outputs.slide:
                 display(self.animation, self._css)
         
-    def set_overall_animation(self, main = 'slide_h',frame = 'slide_v'):
+    def _set_overall_animation(self, main = 'slide_h',frame = 'slide_v'):
         "Set animation for all slides."
-        if main:
+        if main is None:
+            self.__class__._animations['main'] = ''
+        elif main in styles.animations:
             self.__class__._animations['main'] = styles.animations[main]
         else:
-            self.__class__._animations['main'] = ''
+            raise ValueError(f'Animation {main!r} not found. Use None to remove animation or one of {tuple(styles.animations.keys())}')
             
-        if frame:
+        if frame is None:
+            self.__class__._animations['frame'] = ''
+        elif frame in styles.animations:
             self.__class__._animations['frame'] = styles.animations[frame]
         else:
-            self.__class__._animations['frame'] = ''
+            raise ValueError(f'Animation {frame!r} not found. Use None to remove animation or one of {tuple(styles.animations.keys())}')
             
     def set_animation(self, name):
-        "Set animation of this slide."
-        if name:
+        "Set animation of this slide. Provide None if need to stop animation."
+        if name is None:
+            self._animation = html('style', '')
+        elif isinstance(name,str) and name in styles.animations:
             self._animation = html('style',styles.animations[name])
             # See effect of changes
             if self._app._slidelabel != self.label:
@@ -269,7 +309,7 @@ class Slide:
                 with self._app.widgets.outputs.slide:
                     display(self.animation, self._css)
         else:
-            self._animation = None # It should be None, not ''
+            self._animation = None # It should be None, not '' or don't throw error here
             
     def _rebuild_all(self):
         "Update all slides in optimal way when a new slide is added."
@@ -322,6 +362,9 @@ def _build_slide(app, slide_number_str, props_dict = {}, from_cell = False, is_f
     app._slidelabel = _slide.label # Go there to see effects
     _slide.update_display() # Update Slide, it will not come to this point if has same code
     
+    # Update table of contents
+    app._update_toc(change = None)
+    
     if old_slides != list(app._slides_dict.values()): # If there is a change in slides
         _slide._rebuild_all() # Rebuild all slides
         del old_slides # Delete old slides
