@@ -1,5 +1,5 @@
 
-import os, sys, re, textwrap
+import sys, re, textwrap
 from contextlib import contextmanager, suppress
 
 from IPython import get_ipython
@@ -10,8 +10,8 @@ import ipywidgets as ipw
 
 from .extended_md import parse_xmd, _special_funcs, extender as _extender
 from .source import Source
-from .writers import write, iwrite
-from .formatter import bokeh2html, plt2html, highlight, _HTML, serializer
+from .writers import write, iwrite, _fix_repr
+from .formatters import bokeh2html, plt2html, highlight, _HTML, serializer
 from . import utils
 
 _under_slides = {k:getattr(utils,k,None) for k in utils.__all__}
@@ -49,11 +49,11 @@ class _Citation:
         
     @property
     def value(self):
-        _value = self._slide._app._citations_dict.get(self._key, f'Set citation for key {self._key!r} using slides.set_citations or [{self._key}]:&#96;citation text&#96; in markdown.')
-        return f'''<span class = "citation" id="{self._key}">
-            <a href="#{self._key}-back">
-                <sup style="color:var(--accent-color);">{self._id}</sup>
-            </a>{_value}</span>'''
+        _value = self._slide._app._citations_dict.get(self._key, f'Set citation for key {self._key!r} using slides.set_citations or [{self._key}]:\`citation text\` in markdown.')
+        return f'''<div class = "citation" id="{self._key}">
+            <a href="#{self._key}-back"> 
+                <span style="color:var(--accent-color);">{self._id}. </span>
+            </a>{_value}</div>'''
         
         
 class Slides(BaseSlides):
@@ -65,7 +65,6 @@ class Slides(BaseSlides):
         for k,v in _under_slides.items(): # Make All methods available in slides
             setattr(self,k,v)
         
-        self.backtick = '&#96;'
         self.extender   = _extender
         self.plt2html   = plt2html
         self.bokeh2html = bokeh2html
@@ -112,10 +111,12 @@ class Slides(BaseSlides):
         self._nslides =  0 # Real number of slides
         self._max_index = 0 # Maximum index including frames
         self._running_slide = None # For Notes, citations etc in markdown, controlled in Slide class
+        self._next_number = 0 # Auto numbering of slides should be only in python scripts
         
         self.progress_slider = self.widgets.sliders.progress
         self.progress_slider.label = '0' # Set inital value, otherwise it does not capture screenshot if title only
         self.progress_slider.observe(self._update_content,names=['index'])
+        self.progress_slider.observe(self._update_toc,names=['options'])
         
         # All Box of Slides
         self._box =  self.widgets.mainbox
@@ -131,11 +132,15 @@ class Slides(BaseSlides):
         
         **Following syntax works only under currently buidling `slide` or `frame`:**
         
-        - alert`notes&#96;This is slide notes&#96;`  to add notes to current slide
-        - alert`cite&#96;key&#96;` to add citation to current slide
-        - alert`[key]:&#96;citation content&#96;`  to add citation value, use these at start, so can be access in alert`cite&#96;key&#96;`
-        - alert`citations&#96;citations title&#96;`  to add citations at end if `citation_mode = 'global'`.
-        - alert`include&#96;markdown_file.md&#96;` to include a file in markdown format. Useful to have citations in a separate file. (2.0.6+)
+        - alert`notes\`This is slide notes\``  to add notes to current slide
+        - alert`cite\`key\`` to add citation to current slide
+        - alert`[key]:\`citation content\`` to add citation value, use these at start, so can be access in alert`cite\`key\``
+        - alert`citations\`citations title\``  to add citations at end if `citation_mode = 'global'`.
+        - alert`include\`markdown_file.md\`` to include a file in markdown format. Useful to have citations in a separate file. (2.0.6+)
+        - alert`section\`section text\`` to add a section that will appear in the table of contents. (2.1.7+).
+        - alert`toc\`Table of content header text\`` to add a table of contents. Run at last again to collect all. (2.1.7+).
+        - You can escape backtick with backslash: alert`\\\` → \``. (2.1.7+).
+        - A syntax alert`func\`&#63;Markdown&#63;\`` will be converted to alert`func\`Parsed HTML\`` in markdown. Useful to nest special syntax. (2.1.7+).
         - Triple dashes `---` is used to split markdown text in slides inside `from_markdown(start, file_or_str)` function.
         - Double dashes `--` is used to split markdown text in frames. (1.8.9+)
         
@@ -154,7 +159,8 @@ class Slides(BaseSlides):
         - Python code blocks can be exectude by syntax 
         ```markdown
          ```python run source {.CSS_className}
-         my_var = 'Hello'
+         slides = get_slides_instance() # Only available under python code block
+         slides.write('Hello, I was written from python code block using slides instance.')
          ```
         ```
         and source then can be emded with \{\{source\}\} syntax and also \{\{my_var\}\} will show 'Hello'.
@@ -194,7 +200,7 @@ class Slides(BaseSlides):
         
         - Other options include:
         
-        color[blue]`color[blue]&#96;text&#96;`, color[yellow_skyblue]`color[yellow_skyblue]&#96;text&#96;`, ''') + '\n' + ', '.join(f'alert`{k}&#96;{v}&#96;`' for k,v in _special_funcs.items()),
+        color[blue]`color[blue]\`text\``, color[yellow_skyblue]`color[yellow_skyblue]\`text\``, ''') + '\n' + ', '.join(f'alert`{k}\`{v}\``' for k,v in _special_funcs.items()),
         display_inline = False
         ))
         
@@ -246,6 +252,10 @@ class Slides(BaseSlides):
         
         raise KeyError("Slide could be accessed by index, slice or key, got {}".format(key))
     
+    def navigate_to(self,index):
+        "Programatically Navigate to slide by index."
+        self._slideindex = index
+    
     @property
     def notebook_dir(self):
         "Get notebook directory."
@@ -275,7 +285,7 @@ class Slides(BaseSlides):
             for slide in self[:]:
                 _all_citations.update(slide._citations)
             
-            return tuple(sorted(_all_citations.values(), key=lambda x: x._id))
+            return tuple(sorted(_all_citations.values(), key=lambda x: int(x._id)))
         
         return ("No citations in 'inline' or 'footnote' mode",)
     
@@ -296,8 +306,8 @@ class Slides(BaseSlides):
         Citation can be accessed by alert`Slides.citations` property and can be passed to `write` function.
         
         **New in 1.7.2**      
-        In Markdown (under `%%slide int -m` or in `from_markdown`), citations can be created by using alert`cite&#96;key&#96;` syntax and 
-        can be set using alert`[key]:&#96;citationtext&#96;` syntax. If citation_mode is global, they can be shown using alert`citations&#96;citation title&#96;` syntax.
+        In Markdown (under `%%slide int -m` or in `from_markdown`), citations can be created by using alert`cite\`key\`` syntax and 
+        can be set using alert`[key]:\`citationtext\`` syntax. If citation_mode is global, they can be shown using alert`citations\`citation title\`` syntax.
         
         """
         if not self._running_slide:
@@ -308,7 +318,7 @@ class Slides(BaseSlides):
         
         this_slide = self._running_slide
         _cited = _Citation(slide = this_slide, key = key)
-        self._citations_dict[key] = self._citations_dict.get(key, f'Set citation for key {key!r} using slides.set_citations or [{key}]:&#96;citation text&#96; in markdown.') # This to ensure single run shows citation
+        self._citations_dict[key] = self._citations_dict.get(key, f'Set citation for key {key!r}.') # This to ensure single run shows citation
         
         # Set _id for citation
         if self._citation_mode == 'footnote':
@@ -319,15 +329,16 @@ class Slides(BaseSlides):
             if key in prev_keys:
                 _cited._id = str(prev_keys.index(key) + 1)
             else:
-                _cited._id = str(len(prev_keys)) 
+                _cited._id = str(len(prev_keys))
              
         # Return string otherwise will be on different place
-        return f'<a href="#{key}"><sup id ="{key}-back" style="color:var(--accent-color);">{_cited._id}</sup></a>'
+        return f'''<a href="#{key}" class="citelink">
+        <sup id ="{key}-back" style="color:var(--accent-color);">{_cited._id}</sup>
+        </a>''' + (_cited.value.replace('citation', 'citation hidden',1) if self._citation_mode == 'global' else '') # will be hidden by default
     
     def set_citations(self, citations_dict):
         "Set citations in presentation. citations_dict should be a dict of {key:value,...}"
-        self._citations_dict.update({key:self.parse_xmd(value, display_inline=False, rich_outputs = False
-                        ).replace('<p>','',1)[::-1].replace('</p>','',1)[::-1] # Only replace first <p>
+        self._citations_dict.update({key:self.parse_xmd(value, display_inline=False, rich_outputs = False)
                 for key, value in citations_dict.items()})
         
         if self._citation_mode == 'footnote':
@@ -337,6 +348,70 @@ class Slides(BaseSlides):
         else:
             self.notify('Citations updated, please rerun the slides with references to see effect.')
         
+    def section(self,text):
+        """Add section to presentation that will appear in table of contents. 
+        In markdown, section can be created by using alert`%%section\`section text\`` syntax.
+        Sections can be collected using \`Slides.toc\` property or can be written in markdown using alert`toc\`title\`` syntax."""
+        self.running._section = text  
+    
+    @property 
+    def toc(self):
+        """Returns tuple of table of contents that can be passed to write command with desired format. 
+        Run the slide containing alert`Slides.toc` at end as well to see all contents."""
+        sections = []
+        this_index = self[:].index(self.running) if self.running in self[:] else self.running.number # Monkey patching index, would work on next run
+        for slide in self[:this_index]:
+            if slide._section:
+                sections.append(self.html('div', slide._section, style='',className='toc-item prev'))
+        
+        if self.running._section:
+            sections.append(self.html('div', self.running._section, style='',className='toc-item this'))
+        elif sections:
+            sections[-1] = _HTML(sections[-1].value.replace('toc-item prev','toc-item this'))
+        
+        for slide in self[this_index+1:]:
+            if slide._section:
+                sections.append(self.html('div', slide._section, style='',className='toc-item next'))
+            
+        return tuple(sections)
+        
+    
+    def _goto_button(self, slide_number, text,text_before = '', extra_func=None, **kwargs):
+        "See docs of `goto_button`. This is internal function to return button box. extra_func is a function to be called on click after going to slide."
+        if not isinstance(slide_number, (int,float,str)): # keep string for internal use only
+            raise TypeError('Slide number should be an integer or float for accessing frames!')
+        
+        button = ipw.Button(description=text,**kwargs).add_class('GoToButton')
+        def on_click(btn):
+            try:
+                ss = str(slide_number)
+                if '.' in ss:
+                    s,f = ss.split('.')
+                    slide = self._slides_dict[s].frames[int(f)-1]
+                else:
+                    slide = self._slides_dict[ss]
+                
+                self.progress_slider.index = slide.index # let it throw error if slide does not exist
+                if callable(extra_func): # Call extra function if given after chnaging slides, no need for user
+                    extra_func()
+                    
+            except:
+                self.notify(f'Failed to jump to slide {slide_number!r}, it may not exist yet!')
+
+        button.on_click(on_click)
+        
+        html_before = ipw.HTML(_fix_repr(text_before)).add_class('GoToHtml')
+        return ipw.HBox([html_before,button],layout=ipw.Layout(align_items='center')).add_class('GoToBox')
+    
+    def goto_button(self, slide_number, text,text_before = '', **kwargs):
+        """"Jump to slide_number when clicked. give slide_number as integer of float like 1, 3.1 etc.   
+        `text` is the text to be displayed on button.    
+        `text_before` additional text (will be parsed) on left of the Button. It is useful because button will not show up in sceenshot.        
+        `kwargs` are passed to `ipywidgets.Button` function.          
+        **Note:** This button has a CSS classes nested as 'GoToBox' > ('GoToHtml','GoToButton') 
+        that can be used to style it under each slide separately."""
+        return display(self._goto_button(slide_number, text,text_before = text_before, **kwargs))
+        
     def show(self, fix_buttons = False): 
         "Display Slides. If icons do not show, try with `fix_buttons=True`."
         
@@ -379,6 +454,15 @@ class Slides(BaseSlides):
                     self.widgets.htmls.notes
                 ]).add_class('ExtraControls')
     
+    @property
+    def auto_number(self):
+        """Returns slide_number to be used in currently buidling slide. Useful inside python scripts. 
+        Inside a running slide, you can access it's value using `slides.running.number`.  
+        
+        - Don't use in Notebook, otherwise you will be keep adding slides on each run.
+        - Don't mix auto_number with manual numbering unless you know what you are doing."""
+        return self._next_number 
+    
     @property
     def _slideindex(self):
         "Get current slide index"
@@ -404,6 +488,16 @@ class Slides(BaseSlides):
     def _switch_slide(self,old_index, new_index): # this change is provide from _update_content
         self.widgets.outputs.slide.clear_output(wait=False) # Clear last slide CSS
         with self.widgets.outputs.slide:
+            next_slide = self[new_index]
+            css = '''.TOC .toc-item.s{idx} {{font-weight:bold;border-right: 4px solid var(--primary-fg);}}
+            .TOC .toc-item {{border-right: 4px solid var(--secondary-bg);}}'''
+            if next_slide._section: # Slide has itw own section
+                self.html('style',css.format(idx = next_slide.index)).display()
+            else:
+                idxs = [s._index for s in self[:new_index] if s._section] # Get all section indexes before current slide
+                sec_index = idxs[-1] if idxs else 0 # Get last section index
+                self.html('style',css.format(idx = sec_index)).display()
+            
             if self.screenshot.capturing == False:
                 self._iterable[new_index].animation.display()
             self._iterable[new_index].css.display()
@@ -488,12 +582,12 @@ class Slides(BaseSlides):
         slide_number_str = line[0] # First argument is slide number
         
         if '-m' in line[1:]:
-            _frames = re.split(r'^--$|^--\s+$',cell,flags = re.MULTILINE) # Split on --- or ---\s+
+            _frames = re.split(r'^--$|^--\s+$',cell, flags= re.DOTALL | re.MULTILINE) # Split on --- or ---\s+
             if len(_frames) > 1:
                 _frames = [_frames[0] + '\n' + obj for obj in _frames[1:]]
                 
             @self.frames(int(slide_number_str), *_frames)
-            def make_slide(_frame):
+            def make_slide(_frame, idx):
                 #s.clear_display(wait = True) # It piles up otherwise due to replacements
                 parse_xmd(_frame, display_inline = True, rich_outputs = False)
                 self._running_slide._markdown = _frame # Update markdown, # cell_code will be automatuically cleared in `self.frames`
@@ -545,13 +639,17 @@ class Slides(BaseSlides):
             yield s # Useful to use later
     
     def frames(self, slide_number, *objs, repeat = False, frame_height = 'auto', props_dict = {}):
-        """Decorator for inserting frames on slide, define a function with one argument acting on each obj in objs.
-        You can also call it as a function, e.g. `.frames(slide_number = 1,1,2,3,4,5)()` becuase required function is `write` by defualt.
+        """Decorator for inserting frames on slide, define a function with two arguments acting on each obj in objs and current frame index.
+        You can also call it as a function, e.g. `.frames(slide_number = 1,1,2,3,4,5)()` becuase it can write by defualt.
         
         ```python
         @slides.frames(1,a,b,c) # slides 1.1, 1.2, 1.3 with content a,b,c
-        def f(obj):
+        def f(obj, idx):
             do_something(obj)
+            if idx == 0: # Main Slide
+                print('This is main slide')
+            else:
+                print('This is frame', idx)
             
         slides.frames(1,a,b,c)() # Auto writes the frames with same content as above
         slides.frames(1,a,b,c, repeat = True)() # content is [a], [a,b], [a,b,c] from top to bottom
@@ -570,7 +668,7 @@ class Slides(BaseSlides):
         
         No return of defined function required, if any, only should be display/show etc.
         CSS properties from `prop_dict` are applied to all slides from *objs."""
-        def _frames(func = self.write): # default write if called without function
+        def _frames(func = lambda obj, idx:self.write(obj)): # default write if called without function
             if not isinstance(slide_number,int):
                 return print(f'slide_number expects integer, got {slide_number!r}')
             
@@ -593,7 +691,11 @@ class Slides(BaseSlides):
             # build_slide returns old slide with updated display if exists.
             with _build_slide(self, f'{slide_number}', props_dict= props_dict, from_cell = False, is_frameless = False) as this_slide:
                 self.write(self.format_css('.SlideArea',height = frame_height))
-                func(_new_objs[0]) # Main slide content
+                try:
+                    func(_new_objs[0],0) # Main slide content
+                except:
+                    print('WARNING: Function under frames should be defined with two arguments, "obj" and "index"')
+                    func(_new_objs[0])
             
             _new_objs = _new_objs[1:] # Fisrt one is already written
             
@@ -610,7 +712,11 @@ class Slides(BaseSlides):
                 
                 with new_slide._capture(assign = True) as captured:
                     self.write(self.format_css('.SlideArea',height = frame_height))
-                    func(obj)
+                    try:
+                        func(obj,i+1)
+                    except:
+                        print('WARNING: Function under frames should be defined with two arguments, "obj" and "index"')
+                        func(obj)
                 
                 new_slide._from_cell = False
                 new_slide._cell_code = ''    
@@ -624,6 +730,18 @@ class Slides(BaseSlides):
             # Update All displays
             for s in this_slide._frames:
                 s.update_display()
+                # Remove duplicate sections/toasts/notes if any
+                if s._section == this_slide._section:
+                    s._section = None
+                if s._notes == this_slide._notes:
+                    s._notes = ''
+                # Toast has new function each time, needs more than just equal check
+                if s._toast and this_slide._toast: 
+                    if s._toast['func']() == this_slide._toast['func']():
+                        s._toast = None
+            
+            # Update Table of contents
+            self._update_toc(change = None)
             
         return _frames 
 
@@ -651,9 +769,34 @@ class Slides(BaseSlides):
                     jj = f'{j}' if len(frames) < 10 else f'{j:02}' # 99 frames max
                     frame._label = f'{nslide}.{jj}' # Label for frames
                     slides_iterable.append(frame)
-            
+        
         return tuple(slides_iterable)
     
+    def _update_toc(self,change):
+        tocs_dict = {s._section:s for s in self._iterable if s._section}
+        children = children = [
+            ipw.HBox([
+                self.widgets.buttons.home,
+                self.widgets.buttons.end,
+                self.widgets.buttons.toc
+            ]),
+            self.widgets.htmls.tochead
+        ]
+        
+        if not tocs_dict:
+            children.append(ipw.HTML(_fix_repr('No sections found!, create sections with alert`Slides.section` method'
+                    ' or alert`section\`Section content\``/alert`section\`?Section content will be parsed first?\`` in markdown cells')))
+        else:
+            for i,(sec,slide) in enumerate(tocs_dict.items(), start = 1):
+                slide_number = f"{slide._number}.{slide._label.split('.')[1]}" if '.' in slide._label else slide._number
+                text_before = _fix_repr(f'color[var(--accent-color)]`{i}.` {sec}') + f"<p>{slide._label}</p>"
+                extra_func = lambda: self.widgets.buttons.toc.click()
+                p_btn = self._goto_button(slide_number,'', text_before= text_before,extra_func=extra_func)
+                children.append(p_btn.add_class('toc-item').add_class(f's{slide._index}')) # class for dynamic CSS
+                
+        self.widgets.tocbox.children = children
+        
+    
     def create(self, *slide_numbers, props_dict ={}):
         "Create empty slides with given slide numbers. If a slide already exists, it remains same. This is faster than creating one slide each time."
         new_slides = False
