@@ -1,4 +1,4 @@
-__all__ = ['suppress_stdout','details', 'set_dir', 'textbox', 'vspace', 'center',
+__all__ = ['bullets','suppress_output','suppress_stdout','details', 'set_dir', 'textbox', 'vspace', 'center',
             'image','svg','iframe', 'format_html','format_css','alert','colored','keep_format',
             'raw','enable_zoom','html','sig','doc','code','today','sub','sup']
 __all__.extend(['rows','cols','block'])
@@ -8,6 +8,7 @@ __all__.extend([f'block_{c}' for c in 'rgbycma'])
 import os, re
 import datetime
 import inspect
+import textwrap
 from html import escape # Builtin library
 from io import BytesIO # For PIL image
 from contextlib import contextmanager, suppress
@@ -17,11 +18,29 @@ from IPython.core.display import Image, display
 from IPython.utils.capture import capture_output
 import ipywidgets as ipw
 
-from .formatter import fix_ipy_image, _HTML
+from .formatters import fix_ipy_image, _HTML
 from .writers import _fmt_write, _fix_repr
 
 
-backtick = '&#96;'
+def _filter_prints(outputs):
+    new_outputs, new_prints = [], []
+    for out in outputs:
+        if 'text/html'in out.data and re.findall(r'class(.*)CustomPrint',out.data['text/html']):
+            new_prints.append(out)
+        else:
+            new_outputs.append(out)
+    return new_outputs, new_prints
+
+@contextmanager
+def suppress_output(keep_stdout = False):
+    "Suppress output of a block of code. If `keep_stdout` is True, only display data is suppressed. (2.1.5+)"
+    with capture_output() as captured:
+        yield 
+    
+    if keep_stdout:
+        outputs = captured.outputs
+        _, new_prints = _filter_prints(outputs)
+        return display(*new_prints)
 
 @contextmanager
 def suppress_stdout():
@@ -30,12 +49,7 @@ def suppress_stdout():
         yield 
     
     outputs = captured.outputs
-    new_outputs = []
-    for out in outputs:
-        if 'text/html'in out.data and re.findall(r'class(.*)CustomPrint',out.data['text/html']):
-            continue
-        else:
-            new_outputs.append(out)
+    new_outputs, _ = _filter_prints(outputs)
     return display(*new_outputs)
 
     
@@ -140,7 +154,11 @@ def html(tag, children = None,className = None,**node_attrs):
     if children and tag.endswith('/'):
         raise ValueError(f'Parametr `children` should be None for self closing tag {tag!r}')
     
-    node_attrs = {'style':"background:inherit;color:inherit;",**{k.replace('_','-'):v for k,v in node_attrs.items()}} # replace _ with - in keys, and add default style
+    if tag == 'style':
+        node_attrs = {} # Ignore node_attrs for style tag
+    else:
+        node_attrs = {'style':"background:inherit;color:inherit;",**{k.replace('_','-'):v for k,v in node_attrs.items()}} # replace _ with - in keys, and add default style
+    
     attrs = ' '.join(f'{k}="{v}"' for k,v in node_attrs.items()) # Join with space is must
     if className:
         attrs = f'class="{className}" {attrs}'
@@ -187,9 +205,10 @@ def keep_format(plaintext_or_html):
     return _HTML(plaintext_or_html) 
 
 def raw(text, className=None):
-    "Keep shape of text as it is, preserving whitespaces as well."
+    "Keep shape of text as it is (but apply dedent), preserving whitespaces as well. "
     _class = className if className else ''
-    return _HTML(f"<div class='RawText {_class}'>{escape(text)}</div>")
+    escaped_text = escape(textwrap.dedent(text).strip('\n')) # dedent and strip newlines on top and bottom
+    return _HTML(f"<div class='RawText {_class}'>{escaped_text}</div>")
 
 def rows(*objs, className=None):
     "Returns tuple of objects. Use in `write`, `iwrite` for better readiability of writing rows in a column."
@@ -299,4 +318,14 @@ def sub(text):
     return html('sub',text,style="font-size:70%;color:inherit;")
 
 def sup(text):
-    return html('sup',text,style="font-size:70%;color:inherit;")
\ No newline at end of file
+    return html('sup',text,style="font-size:70%;color:inherit;")
+
+def bullets(iterable, ordered = False,marker = None, className = None):
+    """A powerful bullet list. `iterable` could be list of anything that you can pass to `write` command.    
+    `marker` could be a unicode charcter or string, only effects unordered list.
+    """
+    _bullets = []
+    for it in iterable:
+        start = f'<li style="list-style-type:\'{marker} \';">' if (marker and not ordered) else '<li>'
+        _bullets.append(f'{start}{_fmt_write(it)}</li>')
+    return html('div',children=[html('ol' if ordered else 'ul',_bullets, style='')],className = className) # Don't use style, it will remove effect of className
\ No newline at end of file
